@@ -54,12 +54,11 @@
 /* Windows headers */
 #include <X11/Xwindows.h>
 
-
 /* Clipboard module constants */
 #define WIN_CLIPBOARD_WINDOW_CLASS		"xwinclip"
 #define WIN_CLIPBOARD_WINDOW_TITLE		"xwinclip"
 #ifdef HAS_DEVWINDOWS
-# define WIN_MSG_QUEUE_FNAME			"/dev/windows"
+#define WIN_MSG_QUEUE_FNAME			"/dev/windows"
 #endif
 #define WIN_CONNECT_RETRIES			40
 #define WIN_CONNECT_DELAY			4
@@ -80,71 +79,60 @@
  */
 
 extern char *display;
-extern void ErrorF (const char* /*f*/, ...);
-extern void winDebug (const char *format, ...);
-extern void winErrorFVerb (int verb, const char *format, ...);
-
+extern void ErrorF(const char * /*f */ , ...);
+extern void winDebug(const char *format, ...);
+extern void winErrorFVerb(int verb, const char *format, ...);
 
 /*
  * winclipboardinit.c
  */
 
 Bool
-winInitClipboard (void);
-
-HWND
-winClipboardCreateMessagingWindow (void);
+ winInitClipboard(void);
 
+HWND winClipboardCreateMessagingWindow(void);
 
 /*
  * winclipboardtextconv.c
  */
 
 void
-winClipboardDOStoUNIX (char *pszData, int iLength);
+ winClipboardDOStoUNIX(char *pszData, int iLength);
 
 void
-winClipboardUNIXtoDOS (unsigned char **ppszData, int iLength);
-
+ winClipboardUNIXtoDOS(unsigned char **ppszData, int iLength);
 
 /*
  * winclipboardthread.c
  */
 
-void *
-winClipboardProc (void *);
+void *winClipboardProc(void *);
 
 void
-winDeinitClipboard (void);
-
+ winDeinitClipboard(void);
 
 /*
  * winclipboardunicode.c
  */
 
 Bool
-winClipboardDetectUnicodeSupport (void);
-
+ winClipboardDetectUnicodeSupport(void);
 
 /*
  * winclipboardwndproc.c
  */
 
-BOOL
-winClipboardFlushWindowsMessageQueue (HWND hwnd);
+BOOL winClipboardFlushWindowsMessageQueue(HWND hwnd);
 
 LRESULT CALLBACK
-winClipboardWindowProc (HWND hwnd, UINT message, 
-			WPARAM wParam, LPARAM lParam);
-
+winClipboardWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam);
 
 /*
  * winclipboardxevents.c
  */
 
 int
-winClipboardFlushXEvents (HWND hwnd,
-			  int iWindow,
-			  Display *pDisplay,
-			  Bool fUnicodeSupport);
+
+winClipboardFlushXEvents(HWND hwnd,
+                         int iWindow, Display * pDisplay, Bool fUnicodeSupport);
 #endif
